declare const _exports: {
    "Tesla": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MAC AUDIO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Topway": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
};
export = _exports;
