export declare const formatVersion: (version: string | undefined, versionTruncation: 0 | 1 | 2 | 3 | null) => string;
export declare const parseBrowserEngineVersion: (userAgent: string, engine: string) => string | undefined;
