declare const _exports: {
    "360": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "8848": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ace": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Tunisie Telecom": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SFR": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "HTC": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Microsoft": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Nokia": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "CnM": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "RIM": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "CHIA": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Palm": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "HP": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "TiPhone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Apple": {
        "regex": string;
        "models": {
            "regex": string;
            "device": string;
            "model": string;
        }[];
    };
    "MicroMax": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "3Q": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "4Good": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Acteck": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Alba": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "AllCall": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Bravis": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Acer": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Advan": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Advance": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "AGM": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Airness": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Aiwa": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Akai": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Arian Space": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Alcatel": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Allview": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Allwinner": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "altron": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "AMGOO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Amoi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ainol": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Archos": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Axxion": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MEU": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Arnova": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ARRIS": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ask": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "ANS": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "AOC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Assistant": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Ark": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Garmin-Asus": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Asus": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Audiovox": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "AVH": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Avvio": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Azumi Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Barnes & Noble": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "BGH": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Bitel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Blu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Bluegood": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Blackview": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Bluboo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Black Fox": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "bogo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Boway": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Brondi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "VGO TEL": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vivo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vinsoc": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Bird": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Becker": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Beeline": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Beetel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BenQ-Siemens": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BenQ": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Blaupunkt": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Bmobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "bq": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Bush": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "CAGI": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Capitel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Captiva": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Casio": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Casper": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Cat": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Carrefour": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Celkon": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Changhong": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Cherry Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "China Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Comio": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Compal": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Artel": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "ComTrade Tesla": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "ConCorde": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Condor": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Coolpad": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Clarmin": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CORN": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cosmote": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "device": string;
            "model": string;
        }[];
    };
    "Cricket": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Crius Mea": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Crosscall": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "AllDocube": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cube": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CUBOT": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Clout": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Concord": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Crescent": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cyrus": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Datang": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Datsun": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Danew": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Denver": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Dell": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Desay": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "DEXP": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Dbtel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Dialog": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Dicam": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Digi": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Digicel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Digiland": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Digma": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "DoCoMo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Doogee": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Doov": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Dopod": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Doro": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Dune HD": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "DNS": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "E-Boda": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Easypix": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "EBEST": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Echo Mobiles": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ECS": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "EE": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "EKT": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Eks Mobility": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Elephone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Element": {
        "regex": string;
        "model": string;
        "device": string;
    };
    "Elenberg": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ericy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Essential": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "E-tel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Evercoss": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Eurostar": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Eton": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Essentielb": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Facebook": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Rikomagic": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Rinno": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Riviera": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Senseit": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sony": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "brand": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "brand": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "brand"?: undefined;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
            "brand"?: undefined;
        })[];
    };
    "Ergo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Ericsson": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Energizer": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Energy Sistem": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "eTouch": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Etuline": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Storex": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Evertek": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Evolio": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Evolveo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Explay": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "EvroMedia": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "EKO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Extrem": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ezze": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ezio": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Forstar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Foxconn": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Fondi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Fairphone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Famoco": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "FiGO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "FNB": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Fujitsu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "G-TiDE": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Gemini": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "General Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Geotel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ghia": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Gigabyte": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Gigaset": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Ginzzu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Gionee": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Grape": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vizio": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "GOCLEVER": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "GoMobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Gol Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Goly": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Google": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Gradiente": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Grundig": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Hafury": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Haier": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "HannSpree": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hasee": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hisense": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Hi-Level": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hoffmann": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Homtom": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hosin": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hoozo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Minix": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Huawei": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Hyundai": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "i-Joy": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "iBall": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "iRola": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "iRulu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Irbis": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "iBerry": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "iHunt": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "IconBIT": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "LYF": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Lumus": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "M4tel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "IMO Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "iLA": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iNew": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "iPro": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Infinix": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "InFocus": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "InnJoo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Inkti": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Innos": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Innostream": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Insignia": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "INQ": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Intex": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "i-mate": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "i-mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "iKoMo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iOcean": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "iView": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Impression": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "iLife": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iTel": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "iZotron": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "JAY-Tech": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Jiayu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Jolla": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Just5": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kalley": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Kaan": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kazam": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Keneksi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kempler & Strauss": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kiano": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Kingsun": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kocaso": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kogan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Komu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Koobee": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kumai": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "KT-Tech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "KDDI": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kodak": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "KOPO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Koridy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "KRONO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "K-Touch": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Diva": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kyocera": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Krüger&Matz": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "LAIQ": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "AIS": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Lava": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "SKG": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Landvo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Land Rover": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Lanix": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Lark": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "LCT": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Le Pan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Leagoo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Ledstar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "LeEco": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Leotec": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Lephone": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Lenco": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Lenovo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Lexand": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Lexibook": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "LG": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Lingwin": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Logicom": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Konka": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Konrow": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Karbonn": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Sagem": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Coby Kyros": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Mpman": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Majestic": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Manta Multimedia": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Masstel": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Maxwest": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "True Slim": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Maze Speed": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Maze": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mediacom": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Medion": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "MEEG": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Fourel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Meizu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Meitu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Memup": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mecer": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mio": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Miray": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Mitsubishi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MIXC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mobiola": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mobicel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mobiistar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MSI": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MLLED": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mobistel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Mecool": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Modecom": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Mofut": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "BrightSign": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Motorola": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Movic": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MTN": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "MyTab": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MyPhone": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "MyWigo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Myros": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Myria": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "M.T.T.": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Navon": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "NOA": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nobby": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NEC": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Neffos": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nextbit": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Newgen": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Netgear": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NeuImage": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NextBook": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NGM": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nexian": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Noain": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Noblex": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nomu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nomi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "NUU Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NYX Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nous": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nvidia": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "O+": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "O2": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Odys": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Obi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Okapia": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Onda": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "OnePlus": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Realme": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "OPPO": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Opsson": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Orange": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Oukitel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "OKWU": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ouki": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Overmax": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Oysters": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "öwn": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Panacom": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "device": string;
            "model": string;
        }[];
    };
    "Panasonic": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "PCBOX": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "PCD": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "PCD Argentina": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ArmPhone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Pentagram": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "TCL": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "JVC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "phoneOne": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Primepad": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Pioneer": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Pixus": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "PULID": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Point of View": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Pomp": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "PPTV": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "ProScan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "RCA Tablets": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Readboy": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Roku": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Rokit": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Rombica": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Rover": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "RoverPad": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Roadrover": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "RT Project": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "S-TELL": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Safaricom": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Santin": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Siemens": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Soundmax": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Samsung": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Sanei": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Selfix": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sencor": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Senwa": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sky": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Skyworth": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Smartfren": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Smartisan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "STF Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "STK": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Stonex": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SuperSonic": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Supra": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "device": string;
            "model": string;
        }[];
    };
    "Sumvision": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SunVan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SWISSMOBILITY": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Thomson": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Tanix": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Pantech": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ployer": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Plum": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Polaroid": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "PolyPad": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Polytron": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Positivo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Prestigio": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Sanyo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Qilive": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "QMobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Maximus": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Quantum": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Quechua": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ramos": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Razer": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sendo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Turbo-X": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Turbo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Silent Circle": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sigma": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Spice": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sharp": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Simply": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Softbank": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sonim": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Star": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Starmobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Amazon": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Symphony": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Helio": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Syrox": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Qtek": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Q-Touch": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "G-Touch": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "T-Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TB Touch": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Teclast": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Tecno Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "TechPad": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Tesco": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "teXet": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Telefunken": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Telego": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Telenor": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Telit": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ThL": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TIANYU": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Timovi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Tooky": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Tolino": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Top House": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Toplux": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Touchmate": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "TrekStor": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Trevi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "TVC": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "U.S. Cellular": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Uhappy": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Unimax": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Unowhy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "UTStarcom": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ulefone": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "UMIDIGI": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Uniscope": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Unnecto": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Unonu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "UTOK": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vastking": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "ViewSonic": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Vitelcom": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Fengxiang": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "VK Mobile": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vernee": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vertu": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Venso": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Verizon": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Verykool": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vestel": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Videocon": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Vodafone": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Vonino": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Vorago": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Voto": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Voxtel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vulcan": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Walton": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "WellcoM": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Wexler": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Inco": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Wink": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Wiko": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Wieppo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Weimei": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Wileyfox": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Wolder": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Wolfgang": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Wonu": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Woo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Woxter": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "X-View": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "POCO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Xiaomi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Xion": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Xolo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yarvik": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yes": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yezz": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yu": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yuandao": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Yusun": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ytone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zonda": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "ZYQ": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Toshiba": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Vivax": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "MLS": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Fly": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "FinePower": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Freetel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Western Digital": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zeemi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zenek": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zopo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ZTE": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Zuum": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zen": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zync": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Lemhoov": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MTC": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "MegaFon": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Inoi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vertex": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Unknown": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Starway": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Savio": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Simbans": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MYFON": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "X-TIGI": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Xiaolajiao": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ritmix": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Ross&Moor": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "R-TV": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NEXBOX": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "True": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yandex": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "FORME": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Shuttle": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BDF": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Highscreen": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CVTE": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Globex": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Atom": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Qumo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Umax": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Mann": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Unihertz": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Chuwi": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Bezkam": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NG Optics": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "KATV1": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ghong": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Xoro": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Vinga": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Viumee": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Nuvo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sunvell": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ugoos": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Yxtel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Proline": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Yota": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mystery": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Ritzviva": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "DeWalt": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Runbo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NewsMy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Newsday": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Daewoo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Vesta": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Spectrum": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kivi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Divisat": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kanji": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kaiomy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "National": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vsun": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Shift Phones": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "RugGear": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Aligator": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Maxcom": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Luna": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Protruly": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "JFone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Uhans": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Soyes": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Zidoo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Zfiner": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iGet": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iVA": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Phicomm": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Huadoo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Gome": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Voyo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ryte": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vontar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vorke": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Wigor": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NEXON": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "ONN": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "EXO": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Q.Bell": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Datawind": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Droxio": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Goophone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "PocketBook": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Bitmore": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kuliao": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sugar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Subor": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Xshitou": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "JKL": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Gree": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vodacom": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "VKworld": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Mito": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "TWM": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "TWZ": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Onix": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Oale": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Mobo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Macoox": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Prixton": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Magnus": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Newland": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Orbic": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "RED": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Contixo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "E-Ceros": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "How": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Multilaser": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Positivo BGH": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Maxtron": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Philco": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "SEMP TCL": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Newman": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Swipe": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Owwo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TD Systems": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ravoz": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "AT&T": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "BIHEE": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Enot": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kooper": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Lesia": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Anry": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tinai": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Winds": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Asano": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Phonemax": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vipro": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "OzoneHD": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kzen": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Melrose": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Crony": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Takara": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tronsmart": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Amigoo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Lumigon": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Neomi": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Eltex": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Senkatel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Bobarry": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Wortmann": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BB Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "2E": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Billion": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tele2": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Alfawise": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Klipad": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "SQOOL": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "TurboKids": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Jinga": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Twoe": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "iTruck": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Torex": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Doffler": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Oyyu": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Primux": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "iMars": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Logic": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cloudpad": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cloudfone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vsmart": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MiXzo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Openbox": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ziox": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "iDroid": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Aoson": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "FireFly Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "i-Cherry": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "NextTab": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Time2": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sunstech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hotwav": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Tetratab": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Dolamee": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Invin": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Doopro": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "IQM": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nos": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Accent": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Avenzo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Beelink": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MAXVI": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "MDC Store": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "meanIT": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Kenxinda": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "X-BO": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Xgody": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Alcor": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iBrit": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ovvi": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Fero": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ruio": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Transpeed": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "VVETIME": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "A1": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Swisstone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "P-UP": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "iVooMi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Pixelphone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Pixela": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Iris": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Fonos": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Xtouch": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Conquest": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Zatec": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Selenga": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Starlight": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "GEOFOX": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tinmo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Matrix": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Verico": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "TTEC": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "eSTAR": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hometech": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ExMobile": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hipstreet": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Navitech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NorthTech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "UNIWA": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Andowl": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Silelis": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Bluedot": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "device": string;
            "model": string;
        } | {
            "regex": string;
            "model": string;
            "device"?: undefined;
        })[];
    };
    "Planet Computers": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Reach": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "MobiWire": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hezire": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hurricane": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "iSWAG": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Reeder": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "ELARI": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Epik One": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "Altice": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Kult": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Beyond": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "BioRugged": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "VAIO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Spark": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SPC": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Winmax": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Zebra": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Thuraya": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Bkav": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Brandt": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Bigben": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SMARTEC": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Asanzo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Artizlee": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Mintt": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Premio": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Trifone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Bluewave": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Siragon": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Poppox": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Zentality": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Black Bear": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Fortis": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "OpelMobile": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "NuAns": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Koolnee": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Sansui": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sico": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Smadl": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "EXCEED": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Tymes": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Solone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "FarEasTone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Smailo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Colors": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Honeywell": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Electroneum": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "High Q": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Pluzz": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "IKU Mobile": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "IKI Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CG Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "IUNI": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ZH&K": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ordissimo": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Necnot": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Einstein": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "AfriOne": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Connex": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Connectce": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Clementoni": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Cell-C": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "VC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CellAllure": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Eagle": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Invens": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Chico Mobile": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Claresta": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Camfone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Bellphone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Gini": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "MIVO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Jesy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Teknosa": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hyve": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "EWIS": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Leader Phone": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Cavion": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "GLX": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Seeken": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Jivi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Winnovo": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "WE": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Trio": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Seuic": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Centric": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kata": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Leff": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hardkernel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Wiseasy": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Shtrikh-M": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BBK": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "4ife": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Westpoint": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Wintouch": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Aiuto": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Seatel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Ditecma": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Datamini": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "3GNET": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Yoka TV": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Formuler": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Malata": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "IT": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Navcity": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Jiake": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "iQ&T": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Mantra": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Datalogic": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Naomi Phone": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Navitel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Linnex": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Smartab": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SuperTab": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Suzuki": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Philips": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "model": string;
            "device": string;
        })[];
    };
    "INCAR": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "FaRao Pro": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Nabi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "StrawBerry": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Gresso": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Pendoo": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "PiPO": {
        "regex": string;
        "device": string;
        "models": ({
            "regex": string;
            "model": string;
            "device"?: undefined;
        } | {
            "regex": string;
            "device": string;
            "model": string;
        })[];
    };
    "Engel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Genesis": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "InfoKit": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Blloc": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Huskee": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SOLE": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "SOLO": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "OINOM": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Singtech": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sunny": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "TEENO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "v-mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "OASYS": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Aspera": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Vision Touch": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "NOBUX": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hitech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "F150": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "BilimLand": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Greentel": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kyowon": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "LT Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ONYX BOOX": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "GFive": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "KINGZONE": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "M-Tech": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Fantec": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "AURIS": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "YUHO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "2F Mobile": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
};
export = _exports;
