declare const _exports: ({
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions"?: undefined;
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine"?: undefined;
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "28": string;
            "3"?: undefined;
            "15"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "4"?: undefined;
            "5.2"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "3": string;
            "28"?: undefined;
            "15"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "4"?: undefined;
            "5.2"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "15": string;
            "28"?: undefined;
            "3"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "4"?: undefined;
            "5.2"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "7": string;
            "15": string;
            "3.5": string;
            "28"?: undefined;
            "3"?: undefined;
            "4"?: undefined;
            "5.2"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "4": string;
            "28"?: undefined;
            "3"?: undefined;
            "15"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "5.2"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "5.2": string;
            "28"?: undefined;
            "3"?: undefined;
            "15"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "4"?: undefined;
            "2.9.16"?: undefined;
            "2.28"?: undefined;
        };
    };
} | {
    "regex": string;
    "name": string;
    "version": string;
    "engine": {
        "default": string;
        "versions": {
            "2.9.16": string;
            "2.28": string;
            "28"?: undefined;
            "3"?: undefined;
            "15"?: undefined;
            "7"?: undefined;
            "3.5"?: undefined;
            "4"?: undefined;
            "5.2"?: undefined;
        };
    };
})[];
export = _exports;
