declare const _exports: ({
    "regex": string;
    "name": string;
    "version": string;
    "url"?: undefined;
} | {
    "regex": string;
    "name": string;
    "version": string;
    "url": string;
})[];
export = _exports;
