declare const _exports: {
    "1B": string;
    "2B": string;
    "36": string;
    "3B": string;
    "7B": string;
    "AA": string;
    "AB": string;
    "AF": string;
    "AG": string;
    "AL": string;
    "AH": string;
    "AM": string;
    "AO": string;
    "AN": string;
    "AE": string;
    "AD": string;
    "AR": string;
    "AX": string;
    "AV": string;
    "AW": string;
    "A0": string;
    "AT": string;
    "AS": string;
    "VG": string;
    "AC": string;
    "A1": string;
    "BA": string;
    "BM": string;
    "BB": string;
    "BD": string;
    "BS": string;
    "BI": string;
    "BE": string;
    "BH": string;
    "BJ": string;
    "BL": string;
    "BU": string;
    "BN": string;
    "BR": string;
    "BK": string;
    "BX": string;
    "BZ": string;
    "BY": string;
    "BF": string;
    "CA": string;
    "CL": string;
    "C6": string;
    "C0": string;
    "CC": string;
    "C4": string;
    "C2": string;
    "CD": string;
    "C1": string;
    "CX": string;
    "CE": string;
    "CF": string;
    "HC": string;
    "CH": string;
    "CI": string;
    "CK": string;
    "CM": string;
    "CN": string;
    "CO": string;
    "CB": string;
    "CW": string;
    "C3": string;
    "CP": string;
    "CR": string;
    "C5": string;
    "CY": string;
    "CS": string;
    "CT": string;
    "CG": string;
    "CZ": string;
    "CU": string;
    "CV": string;
    "DB": string;
    "DE": string;
    "DG": string;
    "DA": string;
    "DT": string;
    "DS": string;
    "DF": string;
    "DO": string;
    "DR": string;
    "DL": string;
    "DI": string;
    "DD": string;
    "EC": string;
    "EI": string;
    "EL": string;
    "EB": string;
    "EE": string;
    "EZ": string;
    "EU": string;
    "EP": string;
    "ES": string;
    "FA": string;
    "FX": string;
    "F1": string;
    "FB": string;
    "FD": string;
    "FE": string;
    "FF": string;
    "FK": string;
    "FY": string;
    "FR": string;
    "FL": string;
    "FO": string;
    "FM": string;
    "FW": string;
    "FN": string;
    "FS": string;
    "FU": string;
    "GA": string;
    "GH": string;
    "GI": string;
    "GB": string;
    "GE": string;
    "GO": string;
    "HS": string;
    "HA": string;
    "HE": string;
    "HO": string;
    "HJ": string;
    "HU": string;
    "IB": string;
    "IC": string;
    "I2": string;
    "I1": string;
    "I3": string;
    "I4": string;
    "ID": string;
    "IV": string;
    "IW": string;
    "IE": string;
    "IM": string;
    "IR": string;
    "JB": string;
    "JS": string;
    "JA": string;
    "JI": string;
    "JP": string;
    "JO": string;
    "KB": string;
    "KI": string;
    "KM": string;
    "KO": string;
    "KP": string;
    "KN": string;
    "KW": string;
    "KD": string;
    "KY": string;
    "KZ": string;
    "LB": string;
    "LF": string;
    "LG": string;
    "LH": string;
    "LI": string;
    "IF": string;
    "LO": string;
    "LU": string;
    "LL": string;
    "LS": string;
    "LN": string;
    "LX": string;
    "M1": string;
    "MB": string;
    "MC": string;
    "MZ": string;
    "ME": string;
    "MF": string;
    "MI": string;
    "MO": string;
    "MU": string;
    "MS": string;
    "MN": string;
    "MT": string;
    "MX": string;
    "NM": string;
    "MY": string;
    "MR": string;
    "MW": string;
    "NW": string;
    "NR": string;
    "NB": string;
    "NO": string;
    "NV": string;
    "NX": string;
    "NE": string;
    "NF": string;
    "NL": string;
    "NP": string;
    "NS": string;
    "NT": string;
    "OC": string;
    "O1": string;
    "OB": string;
    "O2": string;
    "H2": string;
    "OD": string;
    "OF": string;
    "HH": string;
    "OE": string;
    "OX": string;
    "OG": string;
    "OH": string;
    "OI": string;
    "OM": string;
    "OP": string;
    "ON": string;
    "OO": string;
    "OA": string;
    "OS": string;
    "OR": string;
    "O0": string;
    "OY": string;
    "OV": string;
    "OW": string;
    "OT": string;
    "PL": string;
    "PM": string;
    "PY": string;
    "PP": string;
    "PR": string;
    "PU": string;
    "PW": string;
    "PA": string;
    "PE": string;
    "PH": string;
    "PX": string;
    "PB": string;
    "PF": string;
    "PO": string;
    "PT": string;
    "LY": string;
    "PI": string;
    "PS": string;
    "QA": string;
    "Q2": string;
    "Q1": string;
    "QQ": string;
    "QT": string;
    "QU": string;
    "QZ": string;
    "QM": string;
    "QW": string;
    "RE": string;
    "RK": string;
    "RM": string;
    "SB": string;
    "SA": string;
    "S8": string;
    "SC": string;
    "SE": string;
    "SF": string;
    "S5": string;
    "SW": string;
    "SV": string;
    "SH": string;
    "S1": string;
    "SY": string;
    "SK": string;
    "SS": string;
    "SL": string;
    "S6": string;
    "S7": string;
    "7S": string;
    "LE": string;
    "OZ": string;
    "SN": string;
    "SO": string;
    "S2": string;
    "SI": string;
    "SR": string;
    "SP": string;
    "SU": string;
    "S3": string;
    "SG": string;
    "S0": string;
    "S4": string;
    "ST": string;
    "SX": string;
    "SZ": string;
    "TR": string;
    "TO": string;
    "TA": string;
    "TF": string;
    "TB": string;
    "TZ": string;
    "TU": string;
    "TG": string;
    "TS": string;
    "TV": string;
    "UB": string;
    "UC": string;
    "UH": string;
    "UM": string;
    "UT": string;
    "UR": string;
    "UZ": string;
    "VE": string;
    "VI": string;
    "VV": string;
    "VB": string;
    "VM": string;
    "WI": string;
    "WP": string;
    "WE": string;
    "WF": string;
    "WH": string;
    "WO": string;
    "WT": string;
    "YJ": string;
    "YA": string;
    "YL": string;
    "YN": string;
    "YB": string;
    "XS": string;
    "XI": string;
    "XV": string;
    "ZE": string;
    "ZV": string;
};
export = _exports;
