export declare namespace operatingSystem {
    export const AIX: string;
    export const AND: string;
    export const AMG: string;
    export const ATV: string;
    export const ARL: string;
    export const BTR: string;
    export const SBA: string;
    export const BEO: string;
    export const BLB: string;
    export const QNX: string;
    export const BMP: string;
    export const CES: string;
    export const COS: string;
    export const CYN: string;
    export const DEB: string;
    export const DEE: string;
    export const DFB: string;
    export const FED: string;
    export const FOS: string;
    export const FIR: string;
    export const FRE: string;
    export const BSD: string;
    export const FYD: string;
    export const GNT: string;
    export const GTV: string;
    export const HPX: string;
    export const HAI: string;
    export const IRI: string;
    export const INF: string;
    export const KOS: string;
    export const KNO: string;
    export const KBT: string;
    export const LIN: string;
    export const LBT: string;
    export const VLN: string;
    export const MAC: string;
    export const MAE: string;
    export const MDR: string;
    export const SMG: string;
    export const MCD: string;
    export const MIN: string;
    export const MLD: string;
    export const MOR: string;
    export const NBS: string;
    export const MTK: string;
    export const MRE: string;
    export const WII: string;
    export const NDS: string;
    export const OS2: string;
    export const T64: string;
    export const OBS: string;
    export const ORD: string;
    export const PSP: string;
    export const PS3: string;
    export const RHT: string;
    export const ROS: string;
    export const RSO: string;
    export const REM: string;
    export const RZD: string;
    export const SAB: string;
    export const SSE: string;
    export const SAF: string;
    export const SEE: string;
    export const SLW: string;
    export const SOS: string;
    export const SYL: string;
    export const SYM: string;
    export const SYS: string;
    export const S40: string;
    export const S60: string;
    export const SY3: string;
    export const TDX: string;
    export const TIZ: string;
    export const TOS: string;
    export const UBT: string;
    export const WAS: string;
    export const WTV: string;
    export const WHS: string;
    export const WIN: string;
    export const WCE: string;
    export const WIO: string;
    export const WMO: string;
    export const WPH: string;
    export const WRT: string;
    export const XBX: string;
    export const XBT: string;
    export const YNS: string;
    export const IOS: string;
    export const POS: string;
    export const WOS: string;
}
export declare const osFamilies: {
    "Android": string[];
    "AmigaOS": string[];
    "Apple TV": string[];
    "BlackBerry": string[];
    "Brew": string[];
    "BeOS": string[];
    "Chrome OS": string[];
    "Firefox OS": string[];
    "Gaming Console": string[];
    "Google TV": string[];
    "IBM": string[];
    "iOS": string[];
    "RISC OS": string[];
    "GNU/Linux": string[];
    "Mac": string[];
    "Mobile Gaming Console": string[];
    "Real-time OS": string[];
    "Other Mobile": string[];
    "Symbian": string[];
    "Unix": string[];
    "WebTV": string[];
    "Windows": string[];
    "Windows Mobile": string[];
    "Other Smart TV": string[];
};
