declare const _exports: {
    "Airties": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ALDI NORD": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "ALDI SÜD": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Altech UEC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "AOC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "ARRIS": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Atvio": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "BangOlufsen": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Blaupunkt": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Bush": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Celcus": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Changhong": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "CreNova": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Digihome": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "DMM": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "ELECTRONIA": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Essentielb": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Finlux": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "F&U": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Fuego": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "GoGEN": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Grundig": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Haier": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hi-Level": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hisense": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hitachi": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Horizon": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Hotel": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Humax": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Hyundai": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ikea": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Intek": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Inverto": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "JVC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Kalley": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "KUBO": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Laurus": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "LG": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Lifemaxx": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Linsar": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Loewe": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Luxor": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Manhattan": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MediaTek": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Medion": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Miray": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MStar": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "MTC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Nordmende": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Metz": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Ok": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Panasonic": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "PEAQ": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Philips": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Polaroid": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "PROFiLO": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Qilive": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "REGAL": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Saba": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Salora": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Samsung": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SCBC": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SEG": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Selevision": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sharp": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Skyworth": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Smart": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Sony": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "SWTV": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TD Systems": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Technicolor": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Technika": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "TechniSat": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TechnoTrend": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Techwood": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Telefunken": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "TCL": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Thomson": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "TOKYO": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Toshiba": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "Videoweb": {
        "regex": string;
        "device": string;
        "models": {
            "regex": string;
            "model": string;
        }[];
    };
    "VOX": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "WELLINGTON": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "X.Vision": {
        "regex": string;
        "device": string;
        "model": string;
    };
    "Vestel": {
        "regex": string;
        "device": string;
        "model": string;
    };
};
export = _exports;
