export declare namespace Archos {
    export const regex: string;
    export const device: string;
    export const model: string;
}
export declare namespace Microsoft {
    const regex_1: string;
    export { regex_1 as regex };
    const device_1: string;
    export { device_1 as device };
    export const models: {
        "regex": string;
        "model": string;
    }[];
}
export declare namespace Nintendo {
    const regex_2: string;
    export { regex_2 as regex };
    const device_2: string;
    export { device_2 as device };
    const model_1: string;
    export { model_1 as model };
}
export declare namespace OUYA {
    const regex_3: string;
    export { regex_3 as regex };
    const device_3: string;
    export { device_3 as device };
    const model_2: string;
    export { model_2 as model };
}
export declare namespace Sega {
    const regex_4: string;
    export { regex_4 as regex };
    const device_4: string;
    export { device_4 as device };
    const model_3: string;
    export { model_3 as model };
}
export declare namespace Sony {
    const regex_5: string;
    export { regex_5 as regex };
    const device_5: string;
    export { device_5 as device };
    const model_4: string;
    export { model_4 as model };
}
