declare const _exports: {
    "Android Browser": string[];
    "BlackBerry Browser": string[];
    "Baidu": string[];
    "Amiga": string[];
    "Chrome": string[];
    "Firefox": string[];
    "Internet Explorer": string[];
    "Konqueror": string[];
    "NetFront": string[];
    "NetSurf": string[];
    "Nokia Browser": string[];
    "Opera": string[];
    "Safari": string[];
    "Sailfish Browser": string[];
};
export = _exports;
