export declare namespace Nikon {
    export const regex: string;
    export const device: string;
    export const model: string;
}
export declare namespace Samsung {
    const regex_1: string;
    export { regex_1 as regex };
    const device_1: string;
    export { device_1 as device };
    export const models: {
        "regex": string;
        "model": string;
    }[];
}
